Afforest

Struct Afforest 

pub struct Afforest<NI: Idx>(/* private fields */);
A union find data structure based on [1].

Note, that this data structure requires calling compress before calling find in order to return the correct set id.

[1] Michael Sutton, Tal Ben-Nun, Amnon Barak: “Optimizing Parallel Graph Connectivity Computation via Subgraph Sampling”, Symposium on Parallel and Distributed Processing, IPDPS 2018

Implementations

Source

impl<NI: Idx> Afforest<NI>

pub fn new(size: usize) -> Self

Creates a new disjoint-set struct of size elements.

Examples
use graph::prelude::*;

let af = Afforest::new(3);
af.union(0, 1);
af.compress();

let set0 = af.find(0);
let set1 = af.find(1);
assert_eq!(set0, set1);