EdgeNetworkObservableRead

Trait EdgeNetworkObservableRead 

pub trait EdgeNetworkObservableRead {
    // Required method
    fn is_connected(&self) -> bool;
}
Trait for reading network-level properties of an edge.

Required Methods

fn is_connected(&self) -> bool

Whether this edge represents also an existing physical connection between the peers.

This is obviously settable only between the emitter of the measurement (this node) and arbitrary other node in the graph, but could be used for optimizations and path planning.

Implementors