Type Alias Capacity
pub type Capacity = u128;Expand description
The capacity of a payment channel representing an average amount of messages remaining in the channel.
pub type Capacity = u128;The capacity of a payment channel representing an average amount of messages remaining in the channel.