Trait NodeObservable
pub trait NodeObservable {
type Node: MeasurablePeer + Send;
// Required method
fn record_node(&mut self, observation: NodeObservation<Self::Node>);
}Expand description
Trait for recording node lifecycle observations into the graph.
Required Associated Types
type Node: MeasurablePeer + Send
type Node: MeasurablePeer + Send
The node identifier type that can be measured as a peer.
Required Methods
fn record_node(&mut self, observation: NodeObservation<Self::Node>)
fn record_node(&mut self, observation: NodeObservation<Self::Node>)
Record a new observation for the given node.